package ACME::Test::Foo;
use strict;
use warnings;

our $VERSION = '1.7';    # TRIAL VERSION
sub foo { return 3; }

1;

# ABSTRACT: brand new module ACME::Test::Foo

__END__

=pod

=encoding UTF-8

=head1 NAME

ACME::Test::Foo - brand new module ACME::Test::Foo

=head1 VERSION

version 1.7

=head1 SYNOPSIS

  ...

=head1 DESCRIPTION

Some description here.

=head1 METHODS

=head2 foo

This method does something amazing.

=head1 AUTHOR

alexbyk <alex@alexbyk.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by alexbyk.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
